# keyosk

Simple REST-full application to serve as a ready-to-deploy OAuth2 and
OpenID-Connect authentication provider

[![license](https://img.shields.io/pypi/l/keyosk)](https://opensource.org/licenses/MIT)
[![pypi-version](https://img.shields.io/pypi/v/keyosk)](https://pypi.org/project/tox-poetry-installer/)
[![python-versions](https://img.shields.io/pypi/pyversions/keyosk)](https://www.python.org)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
